# cmem-plugin-mattermost

Send messages to [Mattermost](https://mattermost.com/). channels and users.

This is a plugin for [eccenca](https://eccenca.com) [Corporate Memory](https://documentation.eccenca.com).

You can install it with the [cmemc](https://eccenca.com/go/cmemc) command line
clients like this:

```shell-session
cmemc admin workspace python install cmem-plugin-mattermost
```
